/* mvdir - move directory
 * Copyright (C) 2000 Tachibana Eriko
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */


/* System headers */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/xglob.h>

/* Local headers */
#include "dos_mvdir.h"


/* File scope variables */
static const char program[] = "mvdir";
static const char version[] = "0.90";
static const char date[] = "2000/02/29";
static const char author[] = "Ԃq";


/* File scope function */
static void
print_usage (const char* argv0)
{
  printf ("%s version %s  %s %s.\n", program, version, date, author);
  printf ("usage: %s <from> <to>\n", argv0);
}

/* File scope function */
static void
print_version (void)
{
  printf ("%s version %s\n", program, version);
}


/* Function */
int
main (int argc, char* argv[])
{
  int i;
  char* from = NULL;
  char* to = NULL;
  const char* argv0 = argv[0];

  for (i = 1; i < argc; ++i)
    {
      char* p = argv[i];

      if (*p == '\0')
	continue;

      if (*p != '-')
	{
	  if (from == NULL)
	    {
	      from = p;
	      continue;
	    }
	  else if (to == NULL)
	    {
	      to = p;
	      continue;
	    }
	}

      ++p;
      if (*p == '?' || *p == 'h' || *p == 'H' || strcmp (p, "-help") == 0)
	{
	  print_usage (argv0);		/* gp@\ */
	  return EXIT_SUCCESS;
	}

      else if (*p == 'v' || *p == 'V' || strcmp (p, "-version") == 0)
	{
	  print_version ();		/* o[W\ */
	  return EXIT_SUCCESS;
	}

      else
	{
	  print_usage (argv0);		/* sȈ */
	  return EXIT_FAILURE;
	}
    }

  if (from && to)
    {
      int rc;

      if (MvdirGetID () != MVDIR_ID)
	{
	  puts ("dos_mvdir gݍ܂Ă܂.");
	  return EXIT_FAILURE;
	}
      if ((rc = MvdirMove (from, to)) < 0)
	{
	  puts (strerror (_errcnv (rc)));
	  return EXIT_FAILURE;
	}
    }
  else
    {
      print_usage (argv0);		/* ȗ */
      return EXIT_FAILURE;
    }

  return EXIT_SUCCESS;
}

/* EOF */
